@@ -4,7 +4,8 @@
 #include "fastpca.h"
 
 
-#include "R_ext/Applic.h"
+
+
 
 
 //#include "rsubst.c"
@@ -622,296 +623,6 @@ function(X, m)
 		}
 	}
 
-/////////////////////////
-// new l1median start  //
-/////////////////////////
-
-
-	inline double AddSqr (double &d, double pAdd)
-	{
-		return d += pAdd * pAdd ; 
-	}
-
-	class L1MinStruct
-	{
-	public:
-		L1MinStruct (int n, int p, double *pdX, double *pdParScale = 0) ;
-		~L1MinStruct () ;
-
-		int m_n, m_p, m_pn ;
-		double *m_pdX, *m_pdX_, *m_pdDi, *m_pdM, *m_pdParScale ; //, *m_pdM ;
-
-		double calcall (double *pdM, double *pdMRet) ;
-		double calObj (double *pdM) ;
-		//void sqrtrowsumssq () ;
-
-		int m_nCFn, m_nCGr ;
-
-	} ;
-
-	L1MinStruct::L1MinStruct (int n, int p, double *pdX, double *pdParScale) : m_n (n), m_p (p), m_pn (p * n), m_pdX (pdX), m_pdParScale (pdParScale)
-	{
-		m_pdX_ = new double [n * p] ;
-		m_pdDi = new double [n] ;
-		m_pdM = new double [p] ;	//	set m_pdM to some strange value!!
-		m_nCFn = m_nCGr = 0 ;
-	}
-
-	L1MinStruct::~L1MinStruct ()
-	{
-		delete [] m_pdX_ ;
-		delete [] m_pdDi ;
-		delete [] m_pdM ;
-	}
-
-	void Rtprintf (double *pd, int n)
-	{
-		for (; n; n--)
-			Rprintf ("%0.10f\t", *pd++) ;
-		Rprintf ("\r\n") ;
-	}
-
-	double L1MinStruct::calcall (double *pdM, double *pdMRet)
-	{
-		m_nCGr++ ;
-/*
-		memcpy (m_pdM, pdM, m_p * sizeof (double)) ;
-
-		if (m_pdParScale)
-			VectorMultVector (m_pdM, &m_p, m_pdParScale) ;
-*/
-//Rprintf ("grad:\t") ;
-//Rtprintf (pdM, m_p) ;
-		int r, c ;
-		double *pdX = m_pdX + m_pn, *pdX_ = m_pdX_ + m_pn ;
-
-//		double *pdX = m_pdX, *pdX_ = m_pdX_ ;
-
-		for (r = m_n - 1; r != -1; r--)
-			m_pdDi[r] = 0 ;
-
-
-        //    X. <- centr(X,m)
-         //   d.i <- rowSums(X.^2)
-		
-		for (c = m_p - 1; c != -1; c--)
-		{
-			double dXm = m_pdParScale ? pdM[c] * m_pdParScale[c] : pdM[c] ;
-			//for (r = 0; r < m_n; r++)
-			for (r = m_n - 1; r != -1; r--)
-			{
-				*--pdX_ = *--pdX - dXm ;
-				//*pdX_++ = *pdX++ - dXm ;
-				m_pdDi[r] += *pdX_ * *pdX_ ;
-
-
-
-			}
-		}
-
-		pdX_ = m_pdX_ + m_pn ;
-
-		for (r = m_n - 1; r != -1; r--)
-		{
-			m_pdDi[r] = ::sqrt ((double) m_pdDi[r]) ;
-
-		}
-
-		//	MED <- colSums(X. / sqrt (d.i))
-
-
-		for (c = m_p - 1; c != -1; c--)
-		{
-			double &dXm = pdMRet[c] = 0 ;
-			for (r = m_n - 1; r != -1; r--)
-				dXm -= *--pdX_ / m_pdDi[r] ;
-		}
-
-		return 0 ;
-	}
-
-	double L1MinStruct::calObj (double *pdM)
-	{
-		m_nCFn++ ;
-//Rprintf ("obj: \t") ;
-//Rtprintf (pdM, m_p) ;
-
-		memcpy (m_pdM, pdM, m_p * sizeof (double)) ;
-
-		if (m_pdParScale)
-			VectorMultVector (m_pdM, &m_p, m_pdParScale) ;
-
-		//double *pdCur = m_pdX +  m_n * m_p ;
-
-		double dSum = 0, dRowSum ;
-		int r, c ;
-		for (r = m_n - 1; r != -1; r--)
-		{
-			dRowSum = 0 ;
-			for (c = m_p - 1; c != -1; c--)
-				AddSqr (dRowSum, m_pdX [r + c * m_n] - m_pdM [c]) ;
-
-			dSum += ::sqrt (dRowSum) ;
-		}
-//Rprintf ("Obj. val: %f\r\n", dSum) ;
-		return dSum ;
-	}
-
-	void l1objg(int n, double *pdCurCenter, double *pdRetCenter, void *pDat)
-	{
-		((L1MinStruct *) pDat)->calcall (pdCurCenter, pdRetCenter) ;
-	}
-
-	void l1obj_(int n, double *pdCurCenter, double *ddObj, void *pDat)
-	{
-		*ddObj = ((L1MinStruct *) pDat)->calObj (pdCurCenter) ;
-	}
-
-	extern void l1objg(int n, double *pdCurCenter, double *pdRetCenter, void *pDat) ;
-	extern void l1obj_(int n, double *pdCurCenter, double *ddObj, void *pDat) ;
-
-	double l1obj (int n, double *pdCurCenter, void *pDat)
-	{
-		return ((L1MinStruct *) pDat)->calObj (pdCurCenter) ;
-	}
-
-	extern void l1median_NM(int *pnParam, double *pdParam, double *pdData, double *pdParScale, double *pdMRet)
-	{
-		int &n = pnParam [0], &p = pnParam [1], &nMaxStep = pnParam[2], &nFail = pnParam [3], &nTrace = pnParam [4], &nFnCount = pnParam [5] ;
-		double &dAbsTol = pdParam[0], &dRelTol = pdParam[1], &dRet = pdParam[2], &dAlpha = pdParam[3], &dBeta = pdParam[4], &dGamma = pdParam[5] ;
-
-		double *pdStart = new double [p] ;
-
-		memcpy (pdStart, pdMRet, sizeof (double) * p) ;
-
-		VectorDivVector (pdStart, &p, pdParScale) ;
-
-		L1MinStruct minstruc (n, p, pdData, pdParScale) ;
-
-		nmmin (p, pdStart, pdMRet, &dRet, l1obj, &nFail, dAbsTol, dRelTol, (void *) &minstruc, dAlpha, dBeta, dGamma, nTrace, &nFnCount, nMaxStep) ;
-
-		VectorMultVector (pdMRet, &p, pdParScale) ;
-
-		delete [] pdStart ;
-	}
-
-	extern void l1median_CG(int *pnParam, int *pnParam_Out, double *pdParam, double *pdParam_Out, double *pdData, double *pdParScale, double *pdMRet)
-	{
-		int &n = pnParam [0], &p = pnParam [1], &nMaxStep = pnParam[2], &nTrace = pnParam [3], nType = pnParam [4] ;
-		int &nFail = pnParam_Out [0], &nFnCount = pnParam_Out [1], &nGrCount = pnParam_Out [2] ;
-
-		double &dAbsTol = pdParam[0], &dRelTol = pdParam[1] ;
-		double &dRet = pdParam_Out [0] ;
-		double *pdStart = new double [p] ;
-
-		memcpy (pdStart, pdMRet, sizeof (double) * p) ;
-
-		VectorDivVector (pdStart, &p, pdParScale) ;
-
-		L1MinStruct minstruc (n, p, pdData, pdParScale) ;
-
-		cgmin (p, pdStart, pdMRet, &dRet, l1obj, l1objg, &nFail, dAbsTol, dRelTol, (void *) &minstruc, nType, nTrace, &nFnCount, &nGrCount, nMaxStep) ;
-
-		VectorMultVector (pdMRet, &p, pdParScale) ;
-
-		delete [] pdStart ;
-	}
-
-	extern void l1median_BFGS (int *pnParam_In, int *pnParam_Out, double *pdParam_In, double *pdParam_Out, double *pdData, double *pdParScale, double *pdMRet)
-	{
-		int &n = pnParam_In [0], &p = pnParam_In [1], &nMaxStep = pnParam_In[2], &nTrace = pnParam_In [3], nReport = pnParam_In [4] ;
-		int &nFail = pnParam_Out [0], &nFnCount = pnParam_Out [1], &nGrCount = pnParam_Out [2] ;
-
-		double &dAbsTol = pdParam_In[0], &dRelTol = pdParam_In[1] ;
-		double &dRet = pdParam_Out [0] ;
-
-		VectorDivVector (pdMRet, &p, pdParScale) ;
-
-		L1MinStruct minstruc (n, p, pdData, pdParScale) ;
-
-		int *pnMask = new int [p] ;
-		for (int i = p - 1; i != -1; i--)
-			pnMask[i] = 1 ;
-
-		vmmin (p, pdMRet, &dRet, l1obj, l1objg, nMaxStep, nTrace, pnMask, dAbsTol, dRelTol, nReport, (void *) &minstruc, &nFnCount, &nGrCount, &nFail) ;
-
-		VectorMultVector (pdMRet, &p, pdParScale) ;
-
-		delete [] pnMask ;
-	}
-
-	extern void l1median_SA (int *pnParam_In, int *pnParam_Out, double *pdParam_In, double *pdParam_Out, double *pdData, double *pdParScale, double *pdMRet)
-	{
-		int &n = pnParam_In [0], &p = pnParam_In [1], &nMaxStep = pnParam_In[2], &nTrace = pnParam_In [3], nTMax = pnParam_In [4] ;
-		int &nFnCount = pnParam_Out [0] ;
-
-		double &dTempInit = pdParam_In [0] ;
-		double &dRet = pdParam_Out [0] ;
-
-		VectorDivVector (pdMRet, &p, pdParScale) ;
-
-		L1MinStruct minstruc (n, p, pdData, pdParScale) ;
-
-		samin (p, pdMRet, &dRet, l1obj, nMaxStep, nTMax, dTempInit, nTrace, (void *) &minstruc) ;
-		nFnCount = minstruc.m_nCFn ;
-
-		VectorMultVector (pdMRet, &p, pdParScale) ;
-	}
-	
-	extern void l1median_NLM (int *pnParam, double *pdParam, double *pdData, double *pdMRet, double *pdTypSize)
-	{
-		int &n = pnParam [0], &p = pnParam [1], &nMaxStep = pnParam[2], &nFail = pnParam [3], /*&nTrace = pnParam [4],*//* &nFnCount = pnParam [5],*/ &nMsg = pnParam[6] ;
-		double &dTol = pdParam[0], &dRet = pdParam[1] ;
-
-		double *pdStart = new double [p] ;
-
-		memcpy (pdStart, pdMRet, sizeof (double) * p) ;
-
-		L1MinStruct minstruc (n, p, pdData) ;
-
-		nMsg = 8 ;
-
-		double *pdRetGrad = new double [p] ;
-			double *pdWrk = new double [p * 8] ;
-		double *pdA = new double [p * p] ;
-		optif9 (	p,
-					p,
-					pdStart,
-					l1obj_,
-					l1objg,
-					NULL,
-					(void *) &minstruc,
-					pdTypSize,
-					1,			/*	fscale	*/
-					1,			/*	method	*/
-					1,			/*	iexp	*/
-					&nMsg,
-					-1,			/*	ndigit	*/	//	// C: -1 / R: 12
-					nMaxStep,
-					1,			/*	iagflag	*/
-					0,			/*	iahflag	*/
-					1e-6,		/*	dlt		*/		// 1, //1e-6,
-					dTol, 		/*	gradtl	*/		//pow(DBL_EPSILON, 0.25), //0.1,
-					1000,		/*	stepmx	*/		//	C:1e-6 / R: 1000
-					dTol,		/*	steptl	*/		//sqrt(DBL_EPSILON), //1e-6,			
-					pdMRet,	
-					&dRet,
-					pdRetGrad,
-					&nFail,
-					pdA,
-					pdWrk,
-					&nMaxStep) ;
-
-		delete [] pdStart ;
-		delete [] pdRetGrad ;
-		delete [] pdWrk ;
-		delete [] pdA ;
-	}
-
-///////////////////////
-// new l1median end  //
-///////////////////////
-
 /////////////////////////
 // old l1median start  //
 /////////////////////////
